% pop_tesa_fillGpas()     - replaces removed data using weighted forward
%                           and backward prediction.
%                           Note that either tesa_removedata or
%                           pop_tesa_removedata must be ran prior to this function.
% Usage:
%   >>  EEG = pop_tesa_fillGaps( EEG ); % Pop up window
%   >>  EEG = pop_tesa_fillGaps( EEG,pulse,cor,time_samples,memb,nnei);
%
% Inputs:
%   EEG                 - EEGLAB EEG structure
%*Optional(in set order)
%   pulse               - string describing type of pulse, either
%                         'Sinlge Pulse' or 'Paired Pulse'. If not given as
%                         an input the user is asked to clarify
%   cor                 - flag for extra baseline correction, (default 1: excecute)
%   time_samples        - two point array with the duration of the prediction segments                      
%   memb                - number of embending dimensions (default 50)   
%   nnei                - number of nearest neighbors to be detectd (default 2)
%
% Outputs:
%   EEG                 - EEGLAB EEG structure

function [EEG com] = pop_tesa_fillGaps( EEG, varargin)

com = '';          

%check that data is present
if isempty(EEG.data)
    error('Data is empty');
end
%-----pop-up window-----
if nargin < 2
    
    geometry = {1 [1 0.3] 1 1 1 [1 0.3] 1 1 [1 0.3] 1 1 [1 0.3] 1 [1 0.3]};
    
    uilist = {{'style','text','string','Training set duration','fontweight','bold'}...
             {'style','text','string','Duration of sets before and after TMS(in ms): before, after'}...
             {'style','edit','string',''}...
             {'style','text','string','Note: If left empty the whole epoch will be used','fontAngle','italic'}...
             {}...
             {'style','text','string','Times series reconstruction','fontweight','bold'}...
             {'style','text','string','Number of components for the devision of the time series'}...
             {'style','edit','string','50'}...
             {}...
             {'style','text','string','Nearest Neighbors Search','fontweight','bold'}...
             {'style','text','string','Number of Nearset Neighbors to search for'}...
             {'style','edit','string','2'}...
             {}...
             {'style','text','string','TMS Pulse','fontweight','bold'}...
             {'style', 'text', 'string', 'Paired pulse TMS'} ...
             {'Style', 'checkbox', 'string' 'on/off' 'value' 0 'tag' 'pair'}...
             {}...
             {'style','text','string','Extra Baseline Correction','fontweight','bold'}...
             {'Style', 'checkbox', 'string' 'on/off' 'value' 1 'tag' 'base'}};
    result = inputgui('geometry',geometry,'uilist',uilist,'title','Fill in removed data -- pop_tesa_fillGaps()','helpcom','pophelp(''pop_tesa_fillGaps'')');
    
    if isempty(result), return; end
    % extract varaible values
    time_samples = str2num(result{1,1});
    memb = str2num(result{1,2});
    nnei = str2num(result{1,3});
    check = result{1,4};
    cor = result{1,5};
    
    if check == 1
        pulse = 'Paired Pulse';
    else
        pulse = 'Single Pulse';
    end
    %run script from pop-up
    EEG = tesa_fillGaps(EEG,pulse,cor,time_samples,memb,nnei);
    com = sprintf('%s = pop_tesa_fillGaps(%s, %s, %s, %s, %s):',inputname(1),inputname(1),pulse,mat2str(time_samples),num2str(memb),num2str(nnei));
	
elseif nargin >2
    %run script according to inputs
    EEG = tesa_fillGaps(EEG, varargin{:});
    com = sprintf('%s = pop_tesa_fillGaps(%s, %s):',inputname(1),inputname(1),varargin2str(varargin));
end

end